# 𝙹𝙰𝚁𝚅𝙸𝚂 𝚄𝚂𝙴𝚁𝙱𝙾𝚃 🇮🇳 ™

## A USERBOT WITH MORE SECURITY AND ASSISTANT

 [![JARVIS USERBOT](https://telegra.ph/file/e6223f1abf7720c4938f3.jpg)](https://t.me/JarvisOT)

[![forthebadge made-with-python](https://camo.githubusercontent.com/5392ad6fb7875a2520001270f08309896b6cb25d/687474703a2f2f466f7254686542616467652e636f6d2f696d616765732f6261646765732f6d6164652d776974682d707974686f6e2e737667)](https://www.python.org/)

## Best UserBot To Manage Your Telegram Account

[![Maintenance](https://img.shields.io/badge/Maintained%3F-Yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![GPL-3.0 license](https://img.shields.io/badge/License-GPL3.0-blue.svg)](https://perso.crans.org/besson/LICENSE.html)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/ellerbrock/open-source-badges/)
[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)
![Python Version](https://img.shields.io/badge/Python-v3.9-green)
![Repo Size](https://img.shields.io/github/repo-size/Jarvis-Works/jarvisuserbot)
![Commit Activity](https://img.shields.io/github/commit-activity/w/Jarvis-Works/jarvisuserbot)[![Codacy Badge](https://api.codacy.com/project/badge/Grade/9c31abbf24d14db89a96e5797b6db93e)](https://app.codacy.com/gh/Jarvis-Works/JarvisUserbot?utm_source=github.com&utm_medium=referral&utm_content=Jarvis-Works/JarvisUserbot&utm_campaign=Badge_Grade)
[![HitCount](http://hits.dwyl.com/Jarvis-Works/jarvisuserbot.svg)](http://hits.dwyl.com/Jarvis-Works/jarvisuserbot)
[![Contributors](https://img.shields.io/github/contributors/Jarvis-Works/jarvisuserbot)](https://github.com/Jarvis-Works/jarvisuserbot/graphs/contributors)
![Last Commit](https://img.shields.io/github/last-commit/Jarvis-Works/jarvisuserbot/master)
![Issues](https://img.shields.io/github/issues/Jarvis-Works/jarvisuserbot)
![Pull Requests](https://img.shields.io/github/issues-pr/Jarvis-Works/jarvisuserbot)
[![StyleCI](https://github.styleci.io/repos/288419893/shield?branch=master)](https://github.styleci.io/repos/288419893?branch=master)
[![License](https://img.shields.io/github/license/Jarvis-Works/jarvisuserbot)](LICENSE)
[![CodeFactor](https://www.codefactor.io/repository/github/jarvis-works/jarvisuserbot/badge)](https://www.codefactor.io/repository/github/jarvis-works/jarvisuserbot)

##  Most PowerFul And Better And Secure

## By Team \#JARVIS™

### Speacial Thanks To Friday For Their Assistant Modules Bases

## This Bot is Made With care No Adult Contents and Abusive Memes. If Any Tell in Issue Column With Command Name.

[![ko-fi](https://www.ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/Q5Q620SDB)

## Video Tutorial By Infotel

[![Tutorial_to_deploy](http://img.youtube.com/vi/LJ0zioHgRTg/0.jpg)](http://www.youtube.com/watch?v=LJ0zioHgRTg)


## For any query or want to know how it works join Group And Channel
[![](https://camo.githubusercontent.com/e531cdc1dbdcb78f8ffe767875a6b6d33c43e2e0/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f4a6f696e2d54656c656772616d2532304368616e6e656c2d7265642e7376673f6c6f676f3d54656c656772616d)](https://t.me/jarvisot)

[![](https://camo.githubusercontent.com/7b0a8bb8af0b2466dd1c38a6c1367ddee45ba266/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f4a6f696e2d54656c656772616d25323047726f75702d626c75652e7376673f6c6f676f3d74656c656772616d)](https://t.me/jarvissupportot)

## Installing Heroku

### The Easy Way

[![Deploy To Heroku](https://www.herokucdn.com/deploy/button.svg)](https://heroku.com/deploy?template=https://github.com/Jarvis-Works/jarvisuserbot/)

##  GET STRING SESSION FROM REPL RUN

 [![Run on Repl.it](https://camo.githubusercontent.com/05149b448485553c6f14f6430a45c12dcc79ed3c/68747470733a2f2f7265706c2e69742f62616467652f6769746875622f6a61727669733231303930342f4a6172766973)](https://jarvisuserbot.jarvis210904.repl.run/)

##  The Normal Way

 Simply clone the repository and run the main file:

```text
git clone https://github.com/Jarvis-Works/JARVISuserbot/
cd jarvis
virtualenv -p /usr/bin/python3 venv
. ./venv/bin/activate
pip install -r requirements.txt
# <Create local_config.py with variables as given below>
python3 -m jarvis
```

  An example `local_config.py` file could be: Not All of the variables are mandatory The Userbot should work by setting only the first two variables

```text
from heroku_config import Var

class Development(Var):
  APP_ID = 6
  API_HASH = "eb06d4abfb49dc3eeb1aeb98ae0f581e"
```

## Jarvis Configuration

 The Jarvis Config is situated in `jarvis/jconfig.py`. Heroku Configuration Simply just leave the Config as it is. Local Configuration Fortunately there are no Mandatory vars for the UniBorg Support Config.

##  Mandatory Vars

* Only two of the environment variables are mandatory.
* This is because of `telethon.errors.rpc_error_list.ApiIdPublishedFloodError`
  * `APP_ID`: You can get this value from [https://my.telegram.org](https://my.telegram.org/)
  * `API_HASH`: You can get this value from [https://my.telegram.org](https://my.telegram.org/)
* The userbot will not work without setting the mandatory vars.
